@@ -17,11 +17,15 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
     Changes made by Johan Billing 2000-04-16:
-	 
+
     - Added #defines for JAM_NO_MESSAGE and JAM_CORRUPT_MSG
-    - Added #ifndef linux around typedefs for ushort and ulong
+    - Added #ifndef linux around typedefs for uint16_t and uint32_t
     - Added prototype for JAM_AddEmptyMessage()
-*/	 
+
+    Backported changes from JAMLIB 1.4.7 made by Johan Billing 2003-10-26
+
+    - Added prototype for JAM_DeleteMessage()
+*/
 
 /***********************************************************************
 **
@@ -35,13 +39,7 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <ctype.h>
-
-#ifndef linux
-typedef unsigned short ushort;   /* must be 16 bits wide */
-typedef unsigned long  ulong;    /* must be 32 bits wide */
-#endif
-
-typedef unsigned char  uchar;    /* must be  8 bits wide */
+#include <stdint.h>
 
 /*
 **  Error codes
@@ -79,13 +77,13 @@ typedef unsigned char  uchar;    /* must be  8 bits wide */
 **  Header file information block, stored first in all .JHR files
 */
 typedef struct {
-    uchar  Signature[4];      /* <J><A><M> followed by <NUL> */
-    ulong  DateCreated;       /* Creation date */
-    ulong  ModCounter;        /* Last processed counter */
-    ulong  ActiveMsgs;        /* Number of active (not deleted) msgs */
-    ulong  PasswordCRC;       /* CRC-32 of password to access */
-    ulong  BaseMsgNum;        /* Lowest message number in index file */
-    uchar  RSRVD[1000];       /* Reserved space */
+    char  Signature[4];      /* <J><A><M> followed by <NUL> */
+    uint32_t  DateCreated;       /* Creation date */
+    uint32_t  ModCounter;        /* Last processed counter */
+    uint32_t  ActiveMsgs;        /* Number of active (not deleted) msgs */
+    uint32_t  PasswordCRC;       /* CRC-32 of password to access */
+    uint32_t  BaseMsgNum;        /* Lowest message number in index file */
+    char  RSRVD[1000];       /* Reserved space */
 } s_JamBaseHeader;
 
 /*
@@ -125,26 +123,26 @@ typedef struct {
 **  Message header
 */
 typedef struct {
-    uchar  Signature[4];              /* <J><A><M> followed by <NUL> */
-    ushort Revision;                  /* CURRENTREVLEV */
-    ushort ReservedWord;              /* Reserved */
-    ulong  SubfieldLen;               /* Length of Subfields */
-    ulong  TimesRead;                 /* Number of times message read */
-    ulong  MsgIdCRC;                  /* CRC-32 of MSGID line */
-    ulong  ReplyCRC;                  /* CRC-32 of REPLY line */
-    ulong  ReplyTo;                   /* This msg is a reply to.. */
-    ulong  Reply1st;                  /* First reply to this msg */
-    ulong  ReplyNext;                 /* Next msg in reply chain */
-    ulong  DateWritten;               /* When msg was written */
-    ulong  DateReceived;              /* When msg was received/read */
-    ulong  DateProcessed;             /* When msg was processed by packer */
-    ulong  MsgNum;                    /* Message number (1-based) */
-    ulong  Attribute;                 /* Msg attribute, see "Status bits" */
-    ulong  Attribute2;                /* Reserved for future use */
-    ulong  TxtOffset;                 /* Offset of text in text file */
-    ulong  TxtLen;                    /* Length of message text */
-    ulong  PasswordCRC;               /* CRC-32 of password to access msg */
-    ulong  Cost;                      /* Cost of message */
+    char  Signature[4];              /* <J><A><M> followed by <NUL> */
+    uint16_t Revision;                  /* CURRENTREVLEV */
+    uint16_t ReservedWord;              /* Reserved */
+    uint32_t  SubfieldLen;               /* Length of Subfields */
+    uint32_t  TimesRead;                 /* Number of times message read */
+    uint32_t  MsgIdCRC;                  /* CRC-32 of MSGID line */
+    uint32_t  ReplyCRC;                  /* CRC-32 of REPLY line */
+    uint32_t  ReplyTo;                   /* This msg is a reply to.. */
+    uint32_t  Reply1st;                  /* First reply to this msg */
+    uint32_t  ReplyNext;                 /* Next msg in reply chain */
+    uint32_t  DateWritten;               /* When msg was written */
+    uint32_t  DateReceived;              /* When msg was received/read */
+    uint32_t  DateProcessed;             /* When msg was processed by packer */
+    uint32_t  MsgNum;                    /* Message number (1-based) */
+    uint32_t  Attribute;                 /* Msg attribute, see "Status bits" */
+    uint32_t  Attribute2;                /* Reserved for future use */
+    uint32_t  TxtOffset;                 /* Offset of text in text file */
+    uint32_t  TxtLen;                    /* Length of message text */
+    uint32_t  PasswordCRC;               /* CRC-32 of password to access msg */
+    uint32_t  Cost;                      /* Cost of message */
 } s_JamMsgHeader;
 
 /*
@@ -176,34 +174,34 @@ typedef struct {
 **  Message header Subfield
 */
 typedef struct {
-    ushort LoID;       /* Field ID, 0 - 0xffff */
-    ushort HiID;       /* Reserved for future use */
-    ulong  DatLen;     /* Length of buffer that follows */
-    uchar* Buffer;     /* DatLen bytes of data */
+    uint16_t LoID;       /* Field ID, 0 - 0xffff */
+    uint16_t HiID;       /* Reserved for future use */
+    uint32_t  DatLen;     /* Length of buffer that follows */
+    char* Buffer;     /* DatLen bytes of data */
 } s_JamSubfield;
 
 typedef struct {
-    ushort LoID;       /* Field ID, 0 - 0xffff */
-    ushort HiID;       /* Reserved for future use */
-    ulong  DatLen;     /* Length of buffer that follows */
+    uint16_t LoID;       /* Field ID, 0 - 0xffff */
+    uint16_t HiID;       /* Reserved for future use */
+    uint32_t  DatLen;     /* Length of buffer that follows */
 } s_JamSaveSubfield;
 
 /*
 **  Message index record
 */
 typedef struct {
-    ulong  UserCRC;    /* CRC-32 of destination username */
-    ulong  HdrOffset;  /* Offset of header in .JHR file */
+    uint32_t  UserCRC;    /* CRC-32 of destination username */
+    uint32_t  HdrOffset;  /* Offset of header in .JHR file */
 } s_JamIndex;
 
 /*
 **  Lastread structure, one per user
 */
 typedef struct {
-    ulong  UserCRC;     /* CRC-32 of user name (lowercase) */
-    ulong  UserID;      /* Unique UserID */
-    ulong  LastReadMsg; /* Last read message number */
-    ulong  HighReadMsg; /* Highest read message number */
+    uint32_t  UserCRC;     /* CRC-32 of user name (lowercase) */
+    uint32_t  UserID;      /* Unique UserID */
+    uint32_t  LastReadMsg; /* Last read message number */
+    uint32_t  HighReadMsg; /* Highest read message number */
 } s_JamLastRead;
 
 /*
@@ -216,8 +214,8 @@ typedef struct {
     FILE* LrdFile_PS;      /* File handle for .JLR file */
     int   Errno_I;	   /* last i/o error */
     int   Locked_I;	   /* is area locked? */
-    ulong LastUserPos_I;   /* last position of lastread record */
-    ulong LastUserId_I;    /* userid for the last read lastread record */
+    uint32_t LastUserPos_I;   /* last position of lastread record */
+    uint32_t LastUserId_I;    /* userid for the last read lastread record */
 } s_JamBase;
 
 /*
@@ -225,8 +223,8 @@ typedef struct {
 */
 typedef struct {
     s_JamSubfield** Fields;
-    ulong	    NumFields;
-    ulong	    NumAlloc;
+    uint32_t	    NumFields;
+    uint32_t	    NumAlloc;
 } s_JamSubPacket;
 
 
@@ -235,17 +233,17 @@ typedef struct {
 */
 
 /* mbase.c */
-int JAM_OpenMB          ( uchar* 		Basename_PC,
+int JAM_OpenMB          ( char* 		Basename_PC,
 			  s_JamBase** 		NewArea_PPS );
 						  
 int JAM_CloseMB         ( s_JamBase* 		Area_PS );
 
-int JAM_CreateMB        ( uchar* 		Basename_PC,
-			  ulong 		BaseMsg_I,
+int JAM_CreateMB        ( char* 		Basename_PC,
+			  uint32_t 		BaseMsg_I,
 			  s_JamBase**		NewArea_PPS );
 
 int JAM_RemoveMB        ( s_JamBase* 		Area_PS,
-			  uchar* 		Basename_PC );
+			  char* 		Basename_PC );
 
 int JAM_LockMB		( s_JamBase* 		Area_PS,
 			  int			Timeout_I );
@@ -259,35 +257,38 @@ int JAM_WriteMBHeader	( s_JamBase* 		Area_PS,
 			  s_JamBaseHeader* 	Header_PS );
 								  
 int JAM_FindUser	( s_JamBase* 		Area_PS,
-			  ulong 		UserCrc_I,
-			  ulong 		StartMsg_I,
-			  ulong* 		MsgNo_PI );
+			  uint32_t 		UserCrc_I,
+			  uint32_t 		StartMsg_I,
+			  uint32_t* 		MsgNo_PI );
 
 int JAM_GetMBSize	( s_JamBase* 		Area_PS,
- 			  ulong* 		Messages_PI );
+ 			  uint32_t* 		Messages_PI );
 
 /* message.c */
 
 int JAM_ReadMsgHeader	( s_JamBase* 		Area_PS, 
-			  ulong 		MsgNo_I,
+			  uint32_t 		MsgNo_I,
 			  s_JamMsgHeader*	Header_PS, 
 			  s_JamSubPacket** 	SubfieldPack_PPS );
 			  
 int JAM_ReadMsgText	( s_JamBase* 		Area_PS, 
-			  ulong 		Offset_I,
-			  ulong 		Length_I,
-			  uchar* 		Buffer_PC );
+			  uint32_t 		Offset_I,
+			  uint32_t 		Length_I,
+			  char* 		Buffer_PC );
 							  
 int JAM_AddMessage	( s_JamBase* 		Area_PS,
 			  s_JamMsgHeader*	Header_PS, 
 			  s_JamSubPacket*	SubPack_PS,
-			  uchar*		Text_PC,
-			  ulong			TextLen_I );
+			  char*		Text_PC,
+			  uint32_t			TextLen_I );
 							  
 int JAM_AddEmptyMessage	( s_JamBase* 		Area_PS );
 
+int JAM_DeleteMessage	( s_JamBase*		Base_PS,
+			  uint32_t			MsgNo_I );
+
 int JAM_ChangeMsgHeader	( s_JamBase* 		Area_PS,
-			  ulong 		MsgNo_I,
+			  uint32_t 		MsgNo_I,
 			  s_JamMsgHeader* 	Header_PS );
 
 int JAM_ClearMsgHeader	( s_JamMsgHeader* 	Header_PS );
@@ -297,11 +298,11 @@ int JAM_Errno		( s_JamBase* 		Area_PS );
 /* lastread.c */
 
 int JAM_ReadLastRead	( s_JamBase* 		Area_PS,
-			  ulong 		User_I,
+			  uint32_t 		User_I,
 			  s_JamLastRead* 	Record_PS );
 
 int JAM_WriteLastRead	( s_JamBase* 		Area_PS,
-			  ulong 		User_I,
+			  uint32_t 		User_I,
 			  s_JamLastRead* 	Record_PS );
 
 /* subpacket.c */
@@ -313,13 +314,13 @@ int 		JAM_DelSubPacket	( s_JamSubPacket* SubPack_PS );
 s_JamSubfield* 	JAM_GetSubfield		( s_JamSubPacket* SubPack_PS );
 
 s_JamSubfield*	JAM_GetSubfield_R	( s_JamSubPacket* SubPack_PS , 
-					  ulong* Count_PI);
+					  uint32_t* Count_PI);
 
 int 		JAM_PutSubfield		( s_JamSubPacket* SubPack_PS,
 					  s_JamSubfield*  Field_PS );
 
 /* crc32.c */
 
-ulong JAM_Crc32		( uchar* Buffer_PC, ulong Length_I );
+uint32_t JAM_Crc32		( char* Buffer_PC, uint32_t Length_I );
 
 #endif
