@@ -41,6 +41,14 @@
     - JAM_CreateMB() would not unlock and close the newly created messagebase
       upon failure.
 
+    Changes made by Johan Billing 2004-07-10
+
+    - Updated the Win32-specific parts of the code to make it compatible with
+      newer versions of MinGW (tested with 3.1.0-1):
+
+      * Now uses Sleep() instead of sleep()
+      * Changed _LK_UNLOCK to _LK_UNLCK in jam_Lock()
+      
 */
 
 /***********************************************************************
@@ -66,6 +74,12 @@
 #if defined( __WIN32__ )
 #include <sys/locking.h>
 #include <io.h>
+#include <windows.h>
+
+#if !defined( _LK_UNLCK ) && defined ( _LK_UNLOCK )
+#define _LK_UNLCK _LK_UNLOCK /* For backwards compatibility */
+#endif
+
 #endif
 
 #if defined( __LINUX__ )
@@ -80,7 +94,7 @@
 #endif
 
 #if defined( __WIN32__ )
-#define JAM_Sleep(x) sleep(x*1000)
+#define JAM_Sleep(x) Sleep(x*1000)
 #endif
 
 #if defined( __LINUX__ )
@@ -92,7 +106,7 @@
 **  File-global functions
 **
 ***********************************************************************/
-int jam_Open( s_JamBase* Base_PS, uchar* Filename_PC, char* Mode_PC );
+int jam_Open( s_JamBase* Base_PS, char* Filename_PC, char* Mode_PC );
 int jam_Lock( s_JamBase* Base_PS, int DoLock_I );
 
 
@@ -101,7 +115,7 @@ int jam_Lock( s_JamBase* Base_PS, int DoLock_I );
 **  JAM_OpenMB - Open message base
 **
 ***********************************************************************/
-int JAM_OpenMB( uchar* Basename_PC, s_JamBase** NewArea_PPS )
+int JAM_OpenMB( char* Basename_PC, s_JamBase** NewArea_PPS )
 {
     s_JamBase*  Base_PS;
     int 	Status_I;
@@ -130,8 +144,8 @@ int JAM_OpenMB( uchar* Basename_PC, s_JamBase** NewArea_PPS )
 **  JAM_CreateMB - Create a new message base
 **
 ***********************************************************************/
-int JAM_CreateMB( uchar* 	Basename_PC,
-		  ulong 	BaseMsg_I,
+int JAM_CreateMB( char* 	Basename_PC,
+		  uint32_t 	BaseMsg_I,
 		  s_JamBase** 	NewArea_PPS )
 {
     s_JamBaseHeader	Base_S;
@@ -205,9 +219,9 @@ int JAM_CloseMB( s_JamBase* Base_PS )
 **  JAM_RemoveMB - Remove a message base
 **
 ***********************************************************************/
-int JAM_RemoveMB( s_JamBase* Base_PS, uchar* Basename_PC )
+int JAM_RemoveMB( s_JamBase* Base_PS, char* Basename_PC )
 {
-    uchar Filename_AC[250];
+    char Filename_AC[250];
     int   Status_AI[4];
 
     /* .JHR file */
@@ -246,7 +260,7 @@ int JAM_RemoveMB( s_JamBase* Base_PS, uchar* Basename_PC )
 **  JAM_GetMBSize - Get the number of messages in message base
 **
 ***********************************************************************/
-int JAM_GetMBSize( s_JamBase* Base_PS, ulong* Messages_PI )
+int JAM_GetMBSize( s_JamBase* Base_PS, uint32_t* Messages_PI )
 {
     long Offset_I;
 
@@ -388,11 +402,11 @@ int JAM_WriteMBHeader( s_JamBase* Base_PS, s_JamBaseHeader* Header_PS )
 **
 ***********************************************************************/
 int JAM_FindUser( s_JamBase*	Base_PS,
-		  ulong 	UserCrc_I,
-		  ulong 	StartMsg_I,
-		  ulong* 	MsgNo_PI )
+		  uint32_t 	UserCrc_I,
+		  uint32_t 	StartMsg_I,
+		  uint32_t* 	MsgNo_PI )
 {
-    ulong MsgNo_I;
+    uint32_t MsgNo_I;
 
     /* go to start message */
     if ( fseek( Base_PS->IdxFile_PS, StartMsg_I * sizeof( s_JamIndex ), 
@@ -476,7 +490,7 @@ int jam_Lock( s_JamBase* Base_PS, int DoLock_I )
     if ( DoLock_I )
         Status_I = _locking(Handle_I,_LK_NBLCK,1);
     else
-        Status_I = _locking(Handle_I,_LK_UNLOCK,1);
+        Status_I = _locking(Handle_I,_LK_UNLCK,1);
 
     if ( Status_I )
        return JAM_LOCK_FAILED;
@@ -530,9 +544,9 @@ int jam_Lock( s_JamBase* Base_PS, int DoLock_I )
 **  jam_Open - Open/create message base files
 **
 ***********************************************************************/
-int jam_Open( s_JamBase* Base_PS, uchar* Basename_PC, char* Mode_PC )
+int jam_Open( s_JamBase* Base_PS, char* Basename_PC, char* Mode_PC )
 {
-    uchar Filename_AC[250];
+    char Filename_AC[250];
 
     /* .JHR file */
     sprintf( Filename_AC, "%s%s", Basename_PC, EXT_HDRFILE );
