@@ -4,12 +4,12 @@
 #include <oslib/os.h>
 #include <oslib/ospattern.h>
 
-bool osCheckPattern(uchar *pattern)
+bool osCheckPattern(char *pattern)
 {
    return(TRUE);
 }
 
-bool osMatchPattern(uchar *pattern,uchar *str)
+bool osMatchPattern(char *pattern,char *str)
 {
    int c;
 
@@ -31,7 +31,7 @@ bool osMatchPattern(uchar *pattern,uchar *str)
    return(TRUE);
 }
 
-bool osIsPattern(uchar *pat)
+bool osIsPattern(char *pat)
 {
    if(strchr(pat,'?') || strchr(pat,'*'))
       return(TRUE);
